.. redirect-from:: /users/prev_whats_new/github_stats_3.7.3

.. _github-stats-3-7-3:

GitHub statistics for 3.7.3 (Sep 11, 2023)
==========================================

GitHub statistics for 2023/07/05 (tag: v3.7.2) - 2023/09/11

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 14 issues and merged 48 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/82?closed=1>`__

The following 17 authors contributed 130 commits.

* amiraflak
* Amirreza Aflakparast
* dependabot[bot]
* Elliott Sales de Andrade
* Greg Lucas
* hannah
* Haoying Zhang
* Jody Klymak
* Kritika Verma
* Kyle Sunden
* marbled-toast
* Mateusz Sokół
* Matthew Feickert
* Oscar Gustafsson
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (48):

* :ghpull:`26725`: Backport PR #26719 on branch v3.7.x (Fix issue with missing attribute in Path3DCollection)
* :ghpull:`26723`: Backport PR #26721 on branch v3.7.x (Add a Python 3.12 classifier)
* :ghpull:`26719`: Fix issue with missing attribute in Path3DCollection
* :ghpull:`26721`: Add a Python 3.12 classifier
* :ghpull:`26672`: Backport cibuildwheel updates to v3.7.x
* :ghpull:`26706`: Pin NumPy below v2 for 3.7.x
* :ghpull:`26653`: Backport PR #26597 on branch v3.7.x (Squeeze post-converted values when validating limits)
* :ghpull:`26597`: Squeeze post-converted values when validating limits
* :ghpull:`26582`: MNT: Enable wheels for Python 3.12
* :ghpull:`26616`: Backport PR #26598 on branch v3.7.x (FIX: array labelcolor for Tick)
* :ghpull:`26598`: FIX: array labelcolor for Tick
* :ghpull:`26610`: Backport PR #26538 on branch v3.7.x (Resolves #26421 Added an example for fig comparison decorator)
* :ghpull:`26538`: Resolves #26421 Added an example for fig comparison decorator
* :ghpull:`26574`: Backport PR #26571 on branch v3.7.x ([Doc]: match 3D plot types with others)
* :ghpull:`26571`: [Doc]: match 3D plot types with others
* :ghpull:`26570`: Backport PR #26569 on branch v3.7.x (refactor: constant "ncols" to variables)
* :ghpull:`26569`: refactor: constant "ncols" to variables
* :ghpull:`26555`: Backport PR #26554 on branch v3.7.x (Remove NumPy abs overrides from pylab)
* :ghpull:`26552`: Backport PR #26493: Disable ````add_html_cache_busting```` on Sphinx 7.1+
* :ghpull:`26554`: Remove NumPy abs overrides from pylab
* :ghpull:`26549`: Backport PR #26545 on branch v3.7.x (Fix size inferral when using cairocffi)
* :ghpull:`26545`: Fix size inferral when using cairocffi
* :ghpull:`26544`: Backport PR #26532: Fix input check in Poly3DCollection.__init__
* :ghpull:`26532`: Fix input check in Poly3DCollection.__init__
* :ghpull:`26459`: Backport PR #26458 on branch v3.7.x (Remove soon to be deprecated nan/inf aliases)
* :ghpull:`26458`: Remove soon to be deprecated nan/inf aliases
* :ghpull:`26455`: Backport PR #26452 on branch v3.7.x (ENH: Update numpy exceptions imports)
* :ghpull:`26452`: ENH: Update numpy exceptions imports
* :ghpull:`26439`: Backport PR #26436 on branch v3.7.x (DOC: Add a warning that ticks are not persistent)
* :ghpull:`26432`: Backport PR #26431 on branch v3.7.x (MNT: Unpin pyparsing, xfail error message tests for pyparsing 3.1.0)
* :ghpull:`26436`: DOC: Add a warning that ticks are not persistent
* :ghpull:`26428`: Merge branch v3.7.2-doc into v3.7.x
* :ghpull:`26431`: MNT: Unpin pyparsing, xfail error message tests for pyparsing 3.1.0
* :ghpull:`26412`: Backport PR #26405 on branch v3.7.x (DOC: Clarify the difference between document and section references)
* :ghpull:`26390`: Backport PR #26354 on branch v3.7.x (DOC: contourf antialiased default)
* :ghpull:`26354`: DOC: contourf antialiased default
* :ghpull:`26386`: Backport PR #26370 on branch v3.7.x (Update README.txt )
* :ghpull:`26364`: Backport PR #26361 on branch v3.7.x (LIC: Update the license we bundle the colorbrewer colormap data with)
* :ghpull:`26361`: LIC: Update the license we bundle the colorbrewer colormap data with
* :ghpull:`26322`: Backport PR #26321 on branch v3.7.x (remove quote box from font_manager)
* :ghpull:`26318`: Backport PR #26317 on branch v3.7.x (update the doc string for fancyarrowpatch to link to annotate)
* :ghpull:`26317`: update the doc string for fancyarrowpatch to link to annotate
* :ghpull:`26304`: Backport PR #26300 on branch v3.7.x (FIX: do not warn when calling tight_layout multiple times)
* :ghpull:`26300`: FIX: do not warn when calling tight_layout multiple times
* :ghpull:`26301`: Backport PR #26291 on branch v3.7.x (Get correct renderer for axes_grid1 inset axes with bbox_inches=tight)
* :ghpull:`26298`: Backport PR #26195 on branch v3.7.x ([Doc] link style sheets reference to customization tutorial)
* :ghpull:`26291`: Get correct renderer for axes_grid1 inset axes with bbox_inches=tight
* :ghpull:`26267`: Backport PR #26266 on branch v3.7.x (DOC: Use consistent font for anatomy example)

Issues (14):

* :ghissue:`26732`: [ENH]: Parser errors should mention that commands do not exist
* :ghissue:`26497`: [Bug]: AttributeError: 'Path3DCollection' object has no attribute '_offset_zordered' (possible regression)
* :ghissue:`26588`: [Bug]: Tick class instantiation returns an error when labelcolor is a tuple
* :ghissue:`26421`: [Doc]: demo testing comparison decorator
* :ghissue:`26486`: [Doc]: match 3D plot types listings titles to other titles
* :ghissue:`26560`: [Doc]: ncols parameter hard-coded
* :ghissue:`26553`: [TST] Upcoming dependency test failures
* :ghissue:`26523`: [Bug]: backend_cairo set_context() is broken for cairocffi
* :ghissue:`26420`: Typo in Poly3DCollection constructor
* :ghissue:`26152`: [Bug]: Pyparsing 3.1 breaks tests
* :ghissue:`26336`: [Doc]: GPL compatibility
* :ghissue:`19721`: head size of FancyArrowPatch is "invisibly small" by default
* :ghissue:`26290`: [Bug]: calling fig.tight_layout multiple times
* :ghissue:`26287`: [Bug]: Error while creating inset axes using ``mpl_toolkits.axes_grid1.inset_locator.inset_axes``
